@@ -62,33 +62,7 @@ static std::vector<Ico> parseIcos(const QJsonArray &icoL)
     return icos;
 }
 
-enum MessageType {
-    UndefinedRemark,
-    IgnoreRemark,
-    FeatureRemark,
-    OperatorRemark,
-    TrainFormationRemark,
-    PlatformSectorsRemark,
-};
-
-static constexpr const Load::Category load_value_map[] = {
-    Load::Unknown,
-    Load::Low, // 1
-    Load::Medium, // 2
-    Load::High, // 3
-    Load::Full // 4
-};
-
-
-struct RemarkData {
-    const char *type = nullptr;
-    const char *code = nullptr;
-    MessageType msg = UndefinedRemark;
-    Feature::Type featureType = Feature::NoFeature;
-    Feature::Availability featureAvailability = Feature::Unknown;
-};
-
-static constexpr const RemarkData remarks_map[] = {
+static constexpr const HafasRemarkData remarks_map[] = {
     // different name formats for the line, used by SBB
     { "A", "1", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
     { "A", "2", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
@@ -219,6 +193,16 @@ static constexpr const RemarkData remarks_map[] = {
     { "I", "sj", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
 };
 
+HafasRemarkData HafasMgateParser::lookupRemarkData(QStringView type, QStringView code)
+{
+    for (const auto &r : remarks_map) {
+        if (type == QLatin1StringView(r.type) && code == QLatin1StringView(r.code)) {
+            return r;
+        }
+    }
+    return {};
+}
+
 static std::vector<Message> parseRemarks(const QJsonArray &remL)
 {
     std::vector<Message> rems;
@@ -228,13 +212,7 @@ static std::vector<Message> parseRemarks(const QJsonArray &remL)
 
         const auto type = remObj.value("type"_L1).toString();
         const auto code = remObj.value("code"_L1).toString();
-        RemarkData remark;
-        for (const auto &r : remarks_map) {
-            if (type == QLatin1StringView(r.type) && code == QLatin1StringView(r.code)) {
-                remark = r;
-                break;
-            }
-        }
+        HafasRemarkData remark = HafasMgateParser::lookupRemarkData(type, code);
         qDebug() << type << code << remark.msg <<remObj;
 
         Message m;
@@ -263,9 +241,7 @@ static std::vector<Message> parseRemarks(const QJsonArray &remL)
                     const auto match = rx.match(code);
                     if (match.hasMatch()) {
                         const auto r = match.captured(2).toInt();
-                        if (r >= 0 && r <= 4) {
-                            m.loadInfo.setLoad(load_value_map[r]);
-                        }
+                        m.loadInfo.setLoad(HafasParser::parseLoadLevel(r));
                         if (match.captured(1) != "max"_L1) {
                             m.loadInfo.setSeatingClass(match.captured(1).left(1));
                         }
@@ -371,12 +347,12 @@ static std::vector<LoadInfo> parseLoadInformation(const QJsonArray &tcocL)
     loadInfos.reserve(tcocL.size());
     for (const auto &tcocV : tcocL) {
         const auto tcocObj = tcocV.toObject();
-        const auto r = tcocObj.value(QLatin1String("r")).toInt(-1);
-        if (r < 0 || r > 4) {
+        const auto l = HafasParser::parseLoadLevel(tcocObj.value("r"_L1).toInt(-1));
+        if (l == Load::Unknown) {
             continue;
         }
         LoadInfo loadInfo;
-        loadInfo.setLoad(load_value_map[r]);
+        loadInfo.setLoad(l);
         const auto c = tcocObj.value(QLatin1String("c")).toString();
         loadInfo.setSeatingClass(c == QLatin1String("FIRST") ? QStringLiteral("1") : QStringLiteral("2"));
         loadInfos.push_back(std::move(loadInfo));
