@@ -49,11 +49,11 @@ QString IndividualTransport::modeIconName(IndividualTransport::Mode mode)
 {
     switch (mode) {
         case IndividualTransport::Bike:
-             return u"qrc:///org.kde.kpublictransport/assets/images/bike.svg"_s;
+             return u"qrc:///org.kde.kpublictransport/assets/images/transport-mode-bike.svg"_s;
         case IndividualTransport::Car:
-            return u"qrc:///org.kde.kpublictransport/assets/images/car.svg"_s;
+            return u"qrc:///org.kde.kpublictransport/assets/images/transport-mode-car.svg"_s;
         case IndividualTransport::Walk:
-            return u"qrc:///org.kde.kpublictransport/assets/images/walk.svg"_s;
+            return u"qrc:///org.kde.kpublictransport/assets/images/transport-mode-walk.svg"_s;
     }
 
     return u"question"_s;
