@@ -7,6 +7,8 @@
 #ifndef KPUBLICTRANSPORT_JOURNEYUTIL_P_H
 #define KPUBLICTRANSPORT_JOURNEYUTIL_P_H
 
+#include "kpublictransport_export.h"
+
 class QDateTime;
 class QTimeZone;
 
@@ -29,6 +31,11 @@ namespace JourneyUtil
 
     /** Reinterpret all floating times as times with the given timezone. */
     void applyTimeZone(Journey &jny, const QTimeZone &tz);
+
+    /** Propagate location-based timezone information from corresponding stop point locations.
+     *  @internal only exported for KPublicTransportOnboard
+     */
+    KPUBLICTRANSPORT_EXPORT void propagateTimeZones(Journey &jny);
 }
 
 }
