@@ -16,6 +16,8 @@
 #include "ifopt/ifoptutil.h"
 
 #include <KTimeZone>
+#include <KCountry>
+#include <KCountrySubdivision>
 
 #include <QDebug>
 #include <QHash>
@@ -27,6 +29,7 @@
 #include <cmath>
 
 using namespace KPublicTransport;
+using namespace Qt::Literals;
 
 namespace KPublicTransport {
 
@@ -35,8 +38,8 @@ class LocationPrivate : public QSharedData
 public:
     Location::Type type = Location::Place;
     QString name;
-    float latitude = NAN;
-    float longitude = NAN;
+    double latitude = NAN;
+    double longitude = NAN;
     QTimeZone timeZone;
     QHash<QString, QString> ids;
 
@@ -46,6 +49,8 @@ public:
     QString region;
     QString country;
 
+    int floorLevel = std::numeric_limits<int>::lowest();
+
     QVariant data;
 };
 
@@ -54,16 +59,48 @@ public:
 KPUBLICTRANSPORT_MAKE_GADGET(Location)
 KPUBLICTRANSPORT_MAKE_PROPERTY(Location, Location::Type, type, setType)
 KPUBLICTRANSPORT_MAKE_PROPERTY(Location, QString, name, setName)
-KPUBLICTRANSPORT_MAKE_PROPERTY(Location, float, latitude, setLatitude)
-KPUBLICTRANSPORT_MAKE_PROPERTY(Location, float, longitude, setLongitude)
+KPUBLICTRANSPORT_MAKE_PROPERTY(Location, double, latitude, setLatitude)
+KPUBLICTRANSPORT_MAKE_PROPERTY(Location, double, longitude, setLongitude)
 KPUBLICTRANSPORT_MAKE_PROPERTY(Location, QString, streetAddress, setStreetAddress)
 KPUBLICTRANSPORT_MAKE_PROPERTY(Location, QString, postalCode, setPostalCode)
 KPUBLICTRANSPORT_MAKE_PROPERTY(Location, QString, locality, setLocality)
-KPUBLICTRANSPORT_MAKE_PROPERTY(Location, QString, region, setRegion)
-KPUBLICTRANSPORT_MAKE_PROPERTY(Location, QString, country, setCountry)
+KPUBLICTRANSPORT_MAKE_PROPERTY(Location, int, floorLevel, setFloorLevel)
+
+void Location::setRegion(const QString &regionCode)
+{
+    d.detach();
+    d->region = regionCode;
+}
+
+QString Location::region() const
+{
+    if (d->region.isEmpty() && hasCoordinate()) {
+        auto subdivision = KCountrySubdivision::fromLocation((float)latitude(), (float)longitude());
+        const_cast<Location *>(this)->setRegion(subdivision.code());
+    }
+
+    return d->region;
+}
+
+void Location::setCountry(const QString &countryCode)
+{
+    d.detach();
+    d->country = countryCode;
+}
+
+QString Location::country() const
+{
+    if (d->country.isEmpty() && hasCoordinate()) {
+        auto country = KCountry::fromLocation((float)latitude(), (float)longitude());
+        const_cast<Location *>(this)->setCountry(country.alpha2());
+    }
+
+    return d->country;
+}
+
 KPUBLICTRANSPORT_MAKE_PROPERTY(Location, QVariant, data, setData)
 
-void Location::setCoordinate(float latitude, float longitude)
+void Location::setCoordinate(double latitude, double longitude)
 {
     d.detach();
     d->latitude = latitude;
@@ -75,6 +112,11 @@ bool Location::hasCoordinate() const
     return !std::isnan(d->latitude) && !std::isnan(d->longitude) && std::abs(d->latitude) <= 90.0 && std::abs(d->longitude) <= 180.0;
 }
 
+bool Location::hasFloorLevel() const
+{
+    return d->floorLevel > std::numeric_limits<int>::lowest() && d->floorLevel < std::numeric_limits<int>::max();
+}
+
 bool Location::isEmpty() const
 {
     return !hasCoordinate() && d->name.isEmpty() && d->ids.isEmpty() && d->streetAddress.isEmpty();
@@ -86,7 +128,7 @@ QTimeZone Location::timeZone() const
         return d->timeZone;
     }
     if (hasCoordinate()) {
-        if (const auto tzId = KTimeZone::fromLocation(latitude(), longitude()); tzId) {
+        if (const auto tzId = KTimeZone::fromLocation((float)latitude(), (float)longitude()); tzId) {
             return QTimeZone(tzId);
         }
     }
@@ -120,12 +162,6 @@ RentalVehicleStation Location::rentalVehicleStation() const
     return d->data.value<RentalVehicleStation>();
 }
 
-void Location::setRentalVehicleStation(const RentalVehicleStation &dock)
-{
-    d.detach();
-    d->data = QVariant::fromValue(dock);
-}
-
 RentalVehicle Location::rentalVehicle() const
 {
     return d->data.value<RentalVehicle>();
@@ -161,7 +197,7 @@ struct {
 
 static QStringList splitAndNormalizeName(const QString &name)
 {
-    static const QRegularExpression splitRegExp(QStringLiteral(R"([, \(\)-/\.\[\]])"));
+    static const QRegularExpression splitRegExp(uR"([, \(\)-/\.\[\]])"_s);
     auto l = name.split(splitRegExp, Qt::SkipEmptyParts);
 
     for (auto it = l.begin(); it != l.end();) {
@@ -259,6 +295,7 @@ static int isSameDistanceThreshold(Location::Type type)
     switch (type) {
         case Location::Place:
         case Location::Stop:
+        case Location::Address:
             return 25; // meter
         case Location::CarpoolPickupDropoff:
             return 10;
@@ -365,7 +402,7 @@ bool Location::isSameName(const QString &lhs, const QString &rhs)
     return lhsNormalized == rhsNormalized;
 }
 
-static float mergeCoordinate(float lhs, float rhs)
+static double mergeCoordinate(double lhs, double rhs)
 {
     if (std::isnan(lhs)) {
         return rhs;
@@ -417,6 +454,7 @@ Location Location::merge(const Location &lhs, const Location &rhs)
         case Place:
         case CarpoolPickupDropoff:
         case Stop:
+        case Address:
             break;
         case RentedVehicleStation:
             l.setData(RentalVehicleUtil::merge(lhs.rentalVehicleStation(), rhs.rentalVehicleStation()));
@@ -433,7 +471,7 @@ Location Location::merge(const Location &lhs, const Location &rhs)
 }
 
 // see https://en.wikipedia.org/wiki/Haversine_formula
-float Location::distance(float lat1, float lon1, float lat2, float lon2)
+double Location::distance(double lat1, double lon1, double lat2, double lon2)
 {
     const auto degToRad = M_PI / 180.0;
     const auto earthRadius = 6371000.0; // in meters
@@ -445,10 +483,10 @@ float Location::distance(float lat1, float lon1, float lat2, float lon2)
     return 2.0 * earthRadius * atan2(sqrt(a), sqrt(1.0 - a));
 }
 
-float Location::distance(const Location &lhs, const Location &rhs)
+double Location::distance(const Location &lhs, const Location &rhs)
 {
     if (!lhs.hasCoordinate() || !rhs.hasCoordinate()) {
-        return std::numeric_limits<float>::max();
+        return NAN;
     }
     return Location::distance(lhs.latitude(), lhs.longitude(), rhs.latitude(), rhs.longitude());
 }
@@ -457,7 +495,10 @@ QJsonObject Location::toJson(const Location &loc)
 {
     auto obj = Json::toJson(loc);
     if (loc.d->timeZone.isValid()) {
-        obj.insert(QLatin1String("timezone"), QString::fromUtf8(loc.d->timeZone.id()));
+        obj.insert("timezone"_L1, QString::fromUtf8(loc.d->timeZone.id()));
+    }
+    if (!loc.hasFloorLevel()) {
+        obj.remove("floorLevel"_L1);
     }
 
     if (!loc.d->ids.isEmpty()) {
@@ -465,24 +506,25 @@ QJsonObject Location::toJson(const Location &loc)
         for (auto it = loc.d->ids.constBegin(); it != loc.d->ids.constEnd(); ++it) {
             ids.insert(it.key(), it.value());
         }
-        obj.insert(QLatin1String("identifier"), ids);
+        obj.insert("identifier"_L1, ids);
     }
 
     switch (loc.type()) {
         case Place:
-            obj.remove(QLatin1String("type"));
+            obj.remove("type"_L1);
             [[fallthrough]];
+        case Address:
         case Stop:
         case CarpoolPickupDropoff:
             break;
         case RentedVehicleStation:
-            obj.insert(QLatin1String("rentalVehicleStation"), RentalVehicleStation::toJson(loc.rentalVehicleStation()));
+            obj.insert("rentalVehicleStation"_L1, RentalVehicleStation::toJson(loc.rentalVehicleStation()));
             break;
         case RentedVehicle:
-            obj.insert(QLatin1String("rentalVehicle"), RentalVehicle::toJson(loc.rentalVehicle()));
+            obj.insert("rentalVehicle"_L1, RentalVehicle::toJson(loc.rentalVehicle()));
             break;
         case Equipment:
-            obj.insert(QLatin1String("equipment"), Equipment::toJson(loc.equipment()));
+            obj.insert("equipment"_L1, Equipment::toJson(loc.equipment()));
             break;
     }
 
@@ -494,32 +536,53 @@ QJsonArray Location::toJson(const std::vector<Location> &locs)
     return Json::toJson(locs);
 }
 
+QString Location::iconName() const
+{
+    switch (d->type) {
+        case Location::Stop:
+            return u"qrc:///org.kde.kpublictransport/assets/images/transport-stop.svg"_s;
+        case Location::RentedVehicleStation:
+            return rentalVehicleStation().iconName();
+        case Location::RentedVehicle:
+            return rentalVehicle().vehicleTypeIconName();
+        case Location::Equipment:
+            return equipment().iconName();
+        case Location::CarpoolPickupDropoff:
+            return u"qrc:///org.kde.kpublictransport/assets/images/transport-mode-car.svg"_s;
+        case Location::Address:
+        case Location::Place:
+            break;
+    }
+    return u"map-symbolic"_s;
+}
+
 Location Location::fromJson(const QJsonObject &obj)
 {
     auto loc = Json::fromJson<Location>(obj);
-    const auto tz = obj.value(QLatin1String("timezone")).toString();
+    const auto tz = obj.value("timezone"_L1).toString();
     if (!tz.isEmpty()) {
         loc.setTimeZone(QTimeZone(tz.toUtf8()));
     }
 
-    const auto ids = obj.value(QLatin1String("identifier")).toObject();
+    const auto ids = obj.value("identifier"_L1).toObject();
     for (auto it = ids.begin(); it != ids.end(); ++it) {
         loc.setIdentifier(it.key(), it.value().toString());
     }
 
     switch (loc.type()) {
         case Place:
+        case Address:
         case Stop:
         case CarpoolPickupDropoff:
             break;
         case RentedVehicleStation:
-            loc.setData(RentalVehicleStation::fromJson(obj.value(QLatin1String("rentalVehicleStation")).toObject()));
+            loc.setData(RentalVehicleStation::fromJson(obj.value("rentalVehicleStation"_L1).toObject()));
             break;
         case RentedVehicle:
-            loc.setData(RentalVehicle::fromJson(obj.value(QLatin1String("rentalVehicle")).toObject()));
+            loc.setData(RentalVehicle::fromJson(obj.value("rentalVehicle"_L1).toObject()));
             break;
         case Equipment:
-            loc.setData(Equipment::fromJson(obj.value(QLatin1String("equipment")).toObject()));
+            loc.setData(Equipment::fromJson(obj.value("equipment"_L1).toObject()));
             break;
     }
 
