@@ -29,6 +29,7 @@ class RentalVehicleStation;
 class KPUBLICTRANSPORT_EXPORT Location
 {
     KPUBLICTRANSPORT_GADGET(Location)
+
 public:
     /** Type of location. */
     enum Type {
@@ -38,6 +39,7 @@ public:
         RentedVehicle = 4, ///< a free-floating rental bike/scooter
         Equipment = 8, ///< elevator/escalator
         CarpoolPickupDropoff = 16, ///< a pickup or dropoff location for a carpool trip
+        Address = 32 ///< postal addresses
     };
     Q_ENUM(Type)
     Q_DECLARE_FLAGS(Types, Type)
@@ -49,9 +51,9 @@ public:
     /** Human-readable name of the location. */
     KPUBLICTRANSPORT_PROPERTY(QString, name, setName)
     /** Latitude of the location, in degree, NaN if unknown. */
-    KPUBLICTRANSPORT_PROPERTY(float, latitude, setLatitude)
+    KPUBLICTRANSPORT_PROPERTY(double, latitude, setLatitude)
     /** Longitude of the location, in degree, NaN if unknown. */
-    KPUBLICTRANSPORT_PROPERTY(float, longitude, setLongitude)
+    KPUBLICTRANSPORT_PROPERTY(double, longitude, setLongitude)
 
     /** Street address of the location, if known. */
     KPUBLICTRANSPORT_PROPERTY(QString, streetAddress, setStreetAddress)
@@ -66,6 +68,13 @@ public:
 
     Q_PROPERTY(bool hasCoordinate READ hasCoordinate STORED false)
 
+    /** OSM floor level of this location.
+     *  Not set by default.
+     */
+    KPUBLICTRANSPORT_PROPERTY(int, floorLevel, setFloorLevel)
+    /** Indicates whether the floor level is set. */
+    Q_PROPERTY(bool hasFloorLevel READ hasFloorLevel STORED false)
+
     /** Location type specific data.
      *  Depending on the location type this can be e.g. a RentalVehicleStation or an Equipment instance.
      */
@@ -78,9 +87,15 @@ public:
     /** Equipment information, if applicable for this location. */
     Q_PROPERTY(KPublicTransport::Equipment equipment READ equipment STORED false)
 
+    /** Icon representing the location type.
+     *  Can be a qrc: URL or an XDG icon name.
+     */
+    Q_PROPERTY(QString iconName READ iconName STORED false)
+
 public:
-    void setCoordinate(float latitude, float longitude);
+    void setCoordinate(double latitude, double longitude);
     [[nodiscard]] bool hasCoordinate() const;
+    [[nodiscard]] bool hasFloorLevel() const;
 
     /** Returns @c true if this is an default-constructed location object not specifying any location. */
     [[nodiscard]] bool isEmpty() const;
@@ -106,17 +121,18 @@ public:
     [[nodiscard]] static Location merge(const Location &lhs, const Location &rhs);
 
     /** Compute the distance between two geo coordinates, in meters. */
-    [[nodiscard]] static float distance(float lat1, float lon1, float lat2, float lon2);
+    [[nodiscard]] static double distance(double lat1, double lon1, double lat2, double lon2);
     /** Computes the distance in meters between two locations.
-     *  Returns MAX_INT if one of the arguments has no coordinates set.
+     *  Returns NAN if one of the arguments has no coordinates set.
      */
-    [[nodiscard]] static float distance(const Location &lhs, const Location &rhs);
+    [[nodiscard]] static double distance(const Location &lhs, const Location &rhs);
 
     [[nodiscard]] RentalVehicleStation rentalVehicleStation() const;
-    [[deprecated("use setData instead")]] void setRentalVehicleStation(const RentalVehicleStation &dock);
     [[nodiscard]] RentalVehicle rentalVehicle() const;
     [[nodiscard]] KPublicTransport::Equipment equipment() const;
 
+    [[nodiscard]] QString iconName() const;
+
     /** Serializes one Location object to JSON. */
     [[nodiscard]] static QJsonObject toJson(const Location &loc);
     /** Serializes an array of Location objects to JSON. */
