@@ -38,6 +38,8 @@ public:
     RentalVehicle::VehicleType type = RentalVehicle::Unknown;
     int remainingRange = -1;
     KPublicTransport::RentalVehicleNetwork network;
+    QUrl webBookingUrl;
+    QUrl appBookingUrl;
 };
 }
 
@@ -88,7 +90,7 @@ RentalVehicle::VehicleTypes RentalVehicleStation::supportedVehicleTypes() const
     return types | availableVehicleTypes();
 }
 
-RentalVehicle::VehicleTypes KPublicTransport::RentalVehicleStation::availableVehicleTypes() const
+RentalVehicle::VehicleTypes RentalVehicleStation::availableVehicleTypes() const
 {
     RentalVehicle::VehicleTypes types = {};
     const auto me = QMetaEnum::fromType<RentalVehicle::VehicleType>();
@@ -148,6 +150,17 @@ void RentalVehicleStation::setAvailableVehicles(RentalVehicle::VehicleType type,
     }
 }
 
+QString RentalVehicleStation::iconName() const
+{
+    const auto me = QMetaEnum::fromType<RentalVehicle::VehicleType>();
+    for (auto i = 0; i < me.keyCount() && i < (int)d->capacities.size(); ++i) {
+        if (d->capacities[i] >= 0) {
+            return RentalVehicle::vehicleTypeIconName((RentalVehicle::VehicleType)me.value(i));
+        }
+    }
+    return RentalVehicle::vehicleTypeIconName(RentalVehicle::Bicycle);
+}
+
 bool RentalVehicleStation::isSame(const RentalVehicleStation &lhs, const RentalVehicleStation &rhs)
 {
     return RentalVehicleNetwork::isSame(lhs.network(), rhs.network());
@@ -220,6 +233,8 @@ KPUBLICTRANSPORT_MAKE_GADGET(RentalVehicle)
 KPUBLICTRANSPORT_MAKE_PROPERTY(RentalVehicle, RentalVehicle::VehicleType, type, setType)
 KPUBLICTRANSPORT_MAKE_PROPERTY(RentalVehicle, int, remainingRange, setRemainingRange)
 KPUBLICTRANSPORT_MAKE_PROPERTY(RentalVehicle, RentalVehicleNetwork, network, setNetwork)
+KPUBLICTRANSPORT_MAKE_PROPERTY(RentalVehicle, QUrl, webBookingUrl, setWebBookingUrl)
+KPUBLICTRANSPORT_MAKE_PROPERTY(RentalVehicle, QUrl, appBookingUrl, setAppBookingUrl)
 
 QString RentalVehicle::vehicleTypeIconName(VehicleType type)
 {
