@@ -5,12 +5,13 @@
 
 function parseGps(response)
 {
-    let pos = {};
-    pos.latitude = response.latitude;
-    pos.longitude = response.longitude;
-    pos.speed = response.speed * 3.6; // m/s -> km/h
-    pos.heading = response.heading;
-    return pos;
+    return {
+        latitude: response.latitude,
+        longitude: response.longitude,
+        speed: response.speed * 3.6, // m/s -> km/h
+        heading: response.heading,
+        altitude: response.altitude
+    };
 }
 
 function parseDetails(response)
