@@ -17,51 +17,54 @@ class QNetworkReply;
 class QNetworkRequest;
 class QUrlQuery;
 
+namespace Wikidata {
+class QueryManager;
+
 /** Base class for Wikidata queries. */
-class WikidataQuery : public QObject
+class Query : public QObject
 {
     Q_OBJECT
 public:
-    explicit WikidataQuery(QObject *parent = nullptr);
-    ~WikidataQuery() override;
+    explicit Query(QObject *parent = nullptr);
+    ~Query() override;
 
     enum Error {
         NoError,
         NetworkError
     };
-    Error error();
+    [[nodiscard]] Error error() const;
 
 Q_SIGNALS:
     void finished();
 
 protected:
-    QUrlQuery commonUrlQuery() const;
+    [[nodiscard]] static QUrlQuery commonUrlQuery();
 
-    friend class WikidataQueryManager;
-    virtual QNetworkRequest nextRequest() = 0;
+    friend class QueryManager;
+    [[nodiscard]] virtual QNetworkRequest nextRequest() = 0;
     /** Returns @true if this query is complete, @false if another request is needed. */
-    virtual bool processReply(QNetworkReply *reply) = 0;
+    [[nodiscard]] virtual bool processReply(QNetworkReply *reply) = 0;
 
     Error m_error = NoError;
 };
 
 /** Wikidata multi-entity retrieval query. */
-class WikidataEntitiesQuery : public WikidataQuery
+class EntitiesQuery : public Query
 {
     Q_OBJECT
 public:
-    explicit WikidataEntitiesQuery(QObject *parent = nullptr);
-    ~WikidataEntitiesQuery() override;
+    explicit EntitiesQuery(QObject *parent = nullptr);
+    ~EntitiesQuery() override;
 
     void setItems(std::vector<Wikidata::Q> &&items);
-    std::vector<Wikidata::Item>&& takeResult();
+    [[nodiscard]] std::vector<Wikidata::Item> takeResult();
 
 Q_SIGNALS:
-    void partialResult(WikidataEntitiesQuery *query);
+    void partialResult(EntitiesQuery *query);
 
 private:
-    QNetworkRequest nextRequest() override;
-    bool processReply(QNetworkReply *reply) override;
+    [[nodiscard]] QNetworkRequest nextRequest() override;
+    [[nodiscard]] bool processReply(QNetworkReply *reply) override;
 
     std::vector<Wikidata::Q> m_items;
     std::size_t m_nextBatch = 0;
@@ -69,26 +72,28 @@ private:
 };
 
 /** Wikidata image metadata query. */
-class WikidataImageMetadataQuery : public WikidataQuery
+class ImageMetadataQuery : public Query
 {
     Q_OBJECT
 public:
-    explicit WikidataImageMetadataQuery(QObject *parent = nullptr);
-    ~WikidataImageMetadataQuery() override;
+    explicit ImageMetadataQuery(QObject *parent = nullptr);
+    ~ImageMetadataQuery() override;
 
     void setImages(std::vector<QString> &&images);
-    std::vector<Wikidata::Image>&& takeResult();
+    [[nodiscard]] std::vector<Wikidata::Image> takeResult();
 
 Q_SIGNALS:
-    void partialResult(WikidataImageMetadataQuery *query);
+    void partialResult(ImageMetadataQuery *query);
 
 private:
-    QNetworkRequest nextRequest() override;
-    bool processReply(QNetworkReply *reply) override;
+    [[nodiscard]] QNetworkRequest nextRequest() override;
+    [[nodiscard]] bool processReply(QNetworkReply *reply) override;
 
     std::vector<QString> m_images;
     std::size_t m_nextBatch = 0;
     std::vector<Wikidata::Image> m_result;
 };
 
+}
+
 #endif // WIKIDATAQUERY_H
